@@ -384,6 +384,13 @@ def generate_report(resume_from: int):
 
     logging.info(f"There are {len(members)} to process.")
 
+    # we resume from the resume form, in the order returned by the S3 bucket
+    if resume_from > 0:
+        index_slice = members.index(str(resume_from))
+        members = members[index_slice:]
+
+        logging.info(f"After resume, there are now {len(members)} to process.")
+
     # the results of the parallel processing are dictionaries with
     # the member ID as the key and a dictionary of preservation statistics
     # as the value.
@@ -399,7 +406,6 @@ def generate_report(resume_from: int):
             CODE_BUCKET,
         )
         for member_id in members
-        if int(member_id) >= resume_from
     )
 
     return members
